Command

Enum Command 

pub enum Command<Msg> {
    None,
    Quit,
    Batch(Vec<Command<Msg>>),
    Message(Msg),
    SetTickRate(Duration),
    ExportOntology,
    AgentAction {
        agent_id: String,
        action: String,
        params: Value,
    },
    Task(Box<dyn FnOnce() -> Msg + Send>),
}
A command returned from Model::update to request side effects.

Variants



None

No operation.



Quit

Quit the application.



Batch(Vec<Command<Msg>>)

Execute multiple commands.



Message(Msg)

Produce a message asynchronously after the current update.



SetTickRate(Duration)

Set the tick interval for animation / periodic updates.



ExportOntology

Request that the agent ontology registry be exported to JSON.



AgentAction

Execute an agent action on a widget identified by agent_id.

Fields

agent_id: String
action: String
params: Value


Task(Box<dyn FnOnce() -> Msg + Send>)

Spawn an asynchronous task that eventually produces a message. The boxed closure runs on a background thread and returns a message.